@@ -24,6 +24,13 @@ static void usage()
 	exit (-1);
 }
 
+static bool all_digit(const char *s)
+{
+	const char *start = s;
+	while (isdigit(*s)) s++;
+	return s > start && *s == '\0';
+}
+
 static int ifconfig_ioctl(
 	int fd,
 	const char *ifname,
@@ -64,6 +71,19 @@ static unsigned long ip_cnv (const char *str)
 }
 
 
+/*
+	Print an IP number with a variable assigned (VAR=x.y.z.w)
+*/
+static void ifspec_printip (const char *varname, unsigned long addr)
+{
+	printf ("%s=%lu.%lu.%lu.%lu\n"
+		,varname
+		,(addr>>24)&0xff
+		,(addr>>16)&0xff
+		,(addr>>8)&0xff
+		,addr&0xff);
+}
+
 /*
 	Fetch the IP number of an interface from the kernel.
 	Assume the device is already available in the kernel
@@ -82,57 +102,45 @@ int ifconfig_print (
 		struct {
 			unsigned long addr;
 			unsigned long mask;
-		} solved;
+		} solved = {0xffffffff,0xffffffff};
 		if (addrstr != NULL && addrstr[0] != '\0'){
 			printf ("ADDR=%s\n",addrstr);
 			solved.addr = ip_cnv (addrstr);
 		}else if (ifconfig_ioctl(skfd,ifname,SIOCGIFADDR, &ifr) >= 0){
 			struct sockaddr_in *sin = (struct sockaddr_in*)&ifr.ifr_addr;
-			unsigned long addr = ntohl(sin->sin_addr.s_addr);
-			printf ("ADDR=%lu.%lu.%lu.%lu\n"
-				,(addr>>24)&0xff
-				,(addr>>16)&0xff
-				,(addr>>8)&0xff
-				,addr&0xff);
-			solved.addr = addr;
+			solved.addr = ntohl(sin->sin_addr.s_addr);
+			ifspec_printip ("ADDR",solved.addr);
 			ret = 0;
 		}
+		bool gotmask = false;
 		if (maskstr != NULL && maskstr[0] != '\0'){
-			printf ("NETMASK=%s\n",maskstr);
-			solved.mask = ip_cnv (maskstr);
-		}else		if (ifconfig_ioctl(skfd,ifname,SIOCGIFNETMASK, &ifr) >= 0){
+			gotmask = true;
+			if (all_digit(maskstr)){
+				solved.mask = 0xffffffff;
+				int n = atoi(maskstr);
+				for (int i=n; i<32; i++) solved.mask <<= 1;
+			}else{
+				solved.mask = ip_cnv (maskstr);
+			}
+		}else if (ifconfig_ioctl(skfd,ifname,SIOCGIFNETMASK, &ifr) >= 0){
 			struct sockaddr_in *sin = (struct sockaddr_in*)&ifr.ifr_addr;
-			unsigned long addr = ntohl(sin->sin_addr.s_addr);
-			printf ("NETMASK=%lu.%lu.%lu.%lu\n"
-				,(addr>>24)&0xff
-				,(addr>>16)&0xff
-				,(addr>>8)&0xff
-				,addr&0xff);
-			solved.mask = addr;
-			ret = 0;
+			solved.mask = ntohl(sin->sin_addr.s_addr);
 		}
+		ifspec_printip ("NETMASK",solved.mask);
+
 		if (bcaststr != NULL && bcaststr[0] != '\0'){
 			printf ("BCAST=%s\n",bcaststr);
-		}else if (ifconfig_ioctl(skfd,ifname,SIOCGIFBRDADDR, &ifr) >= 0){
+		}else if (!gotmask
+			&& ifconfig_ioctl(skfd,ifname,SIOCGIFBRDADDR, &ifr) >= 0){
 			struct sockaddr_in *sin = (struct sockaddr_in*)&ifr.ifr_addr;
-			unsigned long addr = ntohl(sin->sin_addr.s_addr);
-			printf ("BCAST=%lu.%lu.%lu.%lu\n"
-				,(addr>>24)&0xff
-				,(addr>>16)&0xff
-				,(addr>>8)&0xff
-				,addr&0xff);
-			ret = 0;
+			unsigned long bcast = ntohl(sin->sin_addr.s_addr);
+			ifspec_printip ("BCAST",bcast);
 		}else{
 			// Can't get it from the kernel, compute it from the IP
 			// and the netmask
-			unsigned long addr = (solved.addr & solved.mask)
+			unsigned long bcast = (solved.addr & solved.mask)
 				| ~solved.mask;
-			printf ("BCAST=%lu.%lu.%lu.%lu\n"
-				,(addr>>24)&0xff
-				,(addr>>16)&0xff
-				,(addr>>8)&0xff
-				,addr&0xff);
-			
+			ifspec_printip ("BCAST",bcast);
 		}
 		close (skfd);
 	}
