@@ -1,28 +1,8 @@
-/*
-	Modified by Jacques Gelinas for the vserver project
-*/
-// $Id: syscall.c,v 1.1.4.4 2003/10/14 15:20:43 ensc Exp $    --*- c++ -*--
-
-// Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
-//  
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; version 2 of the License.
-//  
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//  
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-
-
 #include "linux/vswitch.h"
 #include <errno.h>
 #include <asm/unistd.h>
 #include "old_syscall.p"
+#include <stdio.h>
 
 #ifndef __NR_vserver
 #  define __NR_vserver	273
@@ -59,7 +39,7 @@ extern "C" int call_new_s_context(int nbctx, int ctxs[], unsigned int remove_cap
 		vcmd_new_s_context_v1 data;
 		data.remove_cap = remove_cap;
 		data.flags = flags;
-		ret = vserver (VCMD_new_s_context,nbctx==0 ? 0 : ctxs[0],&data);
+		ret = vserver (VCMD_new_s_context,nbctx==0 ? -2 : ctxs[0],&data);
 	}else{
 		ret = call_old_new_s_context (nbctx,ctxs,remove_cap,flags);
 	}
