@@ -9,7 +9,7 @@
 #include <utime.h>
 #include "vutil.h"
 #include <sys/ioctl.h>
-#include <linux/ext2_fs.h>
+#include <ext2fs/ext2_fs.h>
 
 bool testmode;
 int debug;
@@ -229,18 +229,60 @@ FILE *vutil_execdistcmd (const char *key, const string &vserver, const char *arg
 	FILE *ret = popen (cmd.c_str(),"r");
 	if (ret == NULL){
 		fprintf (stderr,"Can't execute command %s\n",cmd.c_str());
-	}else{
-		#if 0
-		char buf[1000];
-		while (fgets(buf,sizeof(buf)-1,fin)!=NULL){
-			int last = strlen(buf)-1;
-			if (last >= 0) buf[last] = '\0';
-			ret = buf;
-			break;
-		}
-		pclose (fin);
-		#endif
 	}
 	return ret;
 }
 
+int vutil_readconf (const char *name, VSERVER_CONF &conf)
+{
+	int ret = -1;
+	string cmd = "/usr/lib/vserver/printconf.sh ";
+	cmd += name;
+	FILE *fin = popen (cmd.c_str(),"r");
+	if (fin == NULL){
+		fprintf (stderr,"Can't execute command %s\n",cmd.c_str());
+	}else{
+		char buf[1000];
+		while (fgets(buf,sizeof(buf)-1,fin)!=NULL){
+			int last = strlen(buf)-1;
+			if (last >= 0) buf[last] = '\0';
+			char *pt = strchr(buf,'=');
+			if (pt != NULL){
+				*pt++ = '\0';
+				if (strcmp(buf,"ONBOOT")==0){
+					conf.onboot = strcasecmp(pt,"yes")==0;
+				}else if (strcmp(buf,"IPROOT")==0){
+					conf.iproot = pt;
+				}else if (strcmp(buf,"IPROOTDEV")==0){
+					conf.iprootdev = pt;
+				}else if (strcmp(buf,"IPROOTMASK")==0){
+					conf.iprootmask = pt;
+				}else if (strcmp(buf,"S_HOSTNAME")==0){
+					conf.s_hostname = pt;
+				}else if (strcmp(buf,"S_DOMAINNAME")==0){
+					conf.s_domainname = pt;
+				}else if (strcmp(buf,"S_CAPS")==0){
+					conf.s_caps = pt;
+				}else if (strcmp(buf,"S_FLAGS")==0){
+					conf.s_flags = pt;
+				}else if (strcmp(buf,"S_NICE")==0){
+					conf.s_nice = atoi(pt);
+				}else if (strcmp(buf,"PRIORITY")==0){
+					conf.priority = atoi(pt);
+				}else if (strcmp(buf,"VSERVERS_ROOT")==0){
+					conf.vserversroot = pt;
+				}else if (strcmp(buf,"VSERVERDIR")==0){
+					conf.vserverdir = pt;
+				}
+			}
+		}
+		ret = pclose (fin);
+	}
+	return ret;
+}
+
+int vutil_readconf (const string &name, VSERVER_CONF &conf)
+{
+	return vutil_readconf (name.c_str(),conf);
+}
+
